=== added file 'docs/brief_history_of_drizzle.rst'
--- docs/brief_history_of_drizzle.rst	1970-01-01 00:00:00 +0000
+++ docs/brief_history_of_drizzle.rst	2010-10-12 00:06:15 +0000
@@ -0,0 +1,22 @@
+=============
+A Brief History Of Drizzle
+=============
+
+Drizzle was forked by Brian Aker in 2008 after the Sun Acqusition of MySQL
+by Sun Microsystems. It was announced in 2008 at the O'Reilly Open Source
+Conference. 
+
+Drizzle came into being for both social and technical reasons.
+
+On the technical side Drizzle is a micro-kernel design that is designed to
+be as pluggable as possible. Anyone should be able to quickly extend the
+database for whatever their needs are. Drizzle has been designed for modern
+architectures and deployments. Drizzle does not shy away from breaking with
+the past, many of the MySQL "Gotchas" have been removed.
+
+Drizzle is open source software, designed in an organic manner by developers that span different companies. The development process has been geared to one more similar to the Linux Kernel where no single companies owns the source code, or provides all of the developers. In stark difference to MySQL, the goal is to be inclusive as possible and provide stable releases. The social charter of Drizzle encourages diversity and prize respectful dialogue between all participaing parties.
+
+Drizzle today is the largest fork of the MySQL server. At the time writing, core developers span five companies, with as many, and sometimes more then, 30+
+developers participating across different contents each month. Drizzle provides every other week releases and is the most well tested database in the MySQL family tree.
+
+More can be found here http://en.wikipedia.org/wiki/Drizzle_(database_server)

=== added file 'docs/columntypes.rst'
--- docs/columntypes.rst	1970-01-01 00:00:00 +0000
+++ docs/columntypes.rst	2010-10-12 00:06:15 +0000
@@ -0,0 +1,49 @@
+Built in Column Types
+====================
+
+---------------------
+VARCHAR and VARBINARY
+---------------------
+
+A VARCHAR or VARBINARY type is used to store variable length data. Indexes
+on these types are by default the full length of the data stored.
+The only difference between the two types is the COLLATION which is
+used. VARBINARY uses a binary collation for all index usage.
+
+-------------
+TEXT and BLOB
+-------------
+
+A TEXT or BLOB type is used to store data which is over XXX in size. Indexes
+on these types must specificy the number of character or bytes which should
+be used. The only difference between the two types is the COLLATION which is
+used. A BLOB usees a binary collation for all index usage.
+
+---------
+NUMERICAL
+---------
+
+BIGINT and INTEGER exist as Drizzle's two integer numerical types. BIGINT is
+a 64bit integer while INTEGER is a 32bit integer.
+
+DOUBLE is the systems native double type.
+
+DECIMAL is a fixed precision number.
+
+--------
+TEMPORAL
+--------
+
+DATETIME
+
+TIMESTAMP
+
+DATE
+
+----
+ENUM
+----
+
+Enum (enumerated) types are static lists of strings that are defineed on
+table creation. They can be used to represent a collection of string types
+that are sorted based on the order that they are created.

=== added file 'docs/ddl.rst'
--- docs/ddl.rst	1970-01-01 00:00:00 +0000
+++ docs/ddl.rst	2010-10-12 00:06:15 +0000
@@ -0,0 +1,10 @@
+Data Description Language
+========
+
+CREATE SCHEMA <>
+ALTER SCHEMA <>
+DROP SCHEMA <>
+
+CREATE TABLE <>
+ALTER TABLE <>
+DROP TABLE <>

=== added file 'docs/dml.rst'
--- docs/dml.rst	1970-01-01 00:00:00 +0000
+++ docs/dml.rst	2010-10-12 00:06:15 +0000
@@ -0,0 +1,7 @@
+Data Manipulation Language
+========
+
+INSERT
+UPDATE
+DELETE
+REPLACE

=== added file 'docs/how_to_report_a_bug.rst'
--- docs/how_to_report_a_bug.rst	1970-01-01 00:00:00 +0000
+++ docs/how_to_report_a_bug.rst	2010-10-12 00:06:15 +0000
@@ -0,0 +1,5 @@
+================
+How to report a bug
+================
+
+Bugs for Drizzle can be reported at https://bugs.launchpad.net/drizzle.

=== modified file 'docs/index.rst'
--- docs/index.rst	2010-09-29 15:35:26 +0000
+++ docs/index.rst	2010-10-12 00:06:15 +0000
@@ -12,8 +12,24 @@
 The Drizzle team has removed non-essential code, re-factored the remaining
 code and modernized the code base moving to C++.
 
-.. toctree::
-   :maxdepth: 2
+Introduction:
+
+.. toctree::
+   :maxdepth: 2
+
+   preface
+   what_is_drizzle
+   brief_history_of_drizzle
+   how_to_report_a_bug
+
+SQL Language:
+
+.. toctree::
+   :maxdepth: 2
+
+   ddl
+   dml
+   columntypes
 
 Configuration:
 

=== added file 'docs/preface.rst'
--- docs/preface.rst	1970-01-01 00:00:00 +0000
+++ docs/preface.rst	2010-10-12 00:06:15 +0000
@@ -0,0 +1,8 @@
+================
+Preface
+================
+
+This is the official documentation of Drizzle. It has been written by the Drizzle developers and other volunteers in parallel to the development of the Drizzle software. It describes all the functionality that the current version of Drizzle officially supports.
+
+Drizzle makes use of Launchpad.net. You can find code, bug reports, and
+downloads at http://launchpad.net/drizzle

=== added file 'docs/what_is_drizzle.rst'
--- docs/what_is_drizzle.rst	1970-01-01 00:00:00 +0000
+++ docs/what_is_drizzle.rst	2010-10-12 00:06:15 +0000
@@ -0,0 +1,19 @@
+=============
+What is Drizzle?
+=============
+
+Drizzle is a micro-kernel designed database system with relational and
+durability goals built into the kernel as a default design. It supports a
+number of interfaces which are "pluggable" so that the kernel does as little
+as possible. This allows users to extend the database by writing simple
+plugins.
+
+Drizzle supports SQL92, with custom extensions for advanced users.
+
+It has been designed for modern environments which are 64bit, have lots of
+cores, many gigs of memory, and where a database is needed that will fit into the infrastructure
+of the environment (compared to classic solutions where the database is a
+world unto itself).
+
+Drizzle is open source software, and is maintained by a number of
+individuals and companies for the better advancement of all who participate. 

